======
Hibee
======

Hibee is a python web framework that is developed with the RAID Engine.
Rapid Application Intellectual Development (RAID Engine) is developed and mentained by JABA Applets Foundation.

All documentation is in the "``docs``" directory and online at
https://docs.hibeeproject.com/en/stable/. If you're just getting started,
here's how we recommend you read the docs:

* First, read ``docs/intro/install.txt`` for instructions on installing hibee.

* Next, work through the tutorials in order (``docs/intro/tutorial01.txt``,
  ``docs/intro/tutorial02.txt``, etc.).

* If you want to set up an actual deployment server, read
  ``docs/howto/deployment/index.txt`` for instructions.

* You'll probably want to read through the topical guides (in ``docs/topics``)
  next; from there you can jump to the HOWTOs (in ``docs/howto``) for specific
  problems, and check out the reference (``docs/ref``) for gory details.

* See ``docs/README`` for instructions on building an HTML version of the docs.

Docs are updated rigorously. If you find any problems in the docs, or think
they should be clarified in any way, please take 30 seconds to fill out a
ticket here: https://code.hibeeproject.com/newticket

To get more help:

* Join the ``#hibee`` channel on ``irc.libera.chat``. Lots of helpful people
  hang out there. See https://web.libera.chat if you're new to IRC.

* Join the hibee-users mailing list, or read the archives, at
  https://groups.google.com/group/hibee-users.

To contribute to hibee:

* Check out https://docs.hibeeproject.com/en/dev/internals/contributing/ for
  information about getting involved.

To run Hibee's test suite:

* Follow the instructions in the "Unit tests" section of
  ``docs/internals/contributing/writing-code/unit-tests.txt``, published online at
  https://docs.hibeeproject.com/en/dev/internals/contributing/writing-code/unit-tests/#running-the-unit-tests

Supporting the Development of Hibee
====================================

Hibee's development depends on your contributions.

If you depend on Hibee, remember to support the Hibee Software Foundation: https://www.jabaappplets.com/fundraising/
